==> client-java-api-fluent-15.0.2-sources.jar: io/kubernetes/client/openapi/models/V1DaemonSetConditionBuilder.java <==
/*
Copyright 2022 The Kubernetes Authors.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;

public class V1DaemonSetConditionBuilder
    extends V1DaemonSetConditionFluentImpl<V1DaemonSetConditionBuilder>
    implements VisitableBuilder<
        io.kubernetes.client.openapi.models.V1DaemonSetCondition,
        io.kubernetes.client.openapi.models.V1DaemonSetConditionBuilder> {
  public V1DaemonSetConditionBuilder() {
    this(false);
  }

  public V1DaemonSetConditionBuilder(Boolean validationEnabled) {
    this(new V1DaemonSetCondition(), validationEnabled);
  }

  public V1DaemonSetConditionBuilder(V1DaemonSetConditionFluent<?> fluent) {
    this(fluent, false);
  }

  public V1DaemonSetConditionBuilder(
      io.kubernetes.client.openapi.models.V1DaemonSetConditionFluent<?> fluent,
      java.lang.Boolean validationEnabled) {
    this(fluent, new V1DaemonSetCondition(), validationEnabled);
  }

  public V1DaemonSetConditionBuilder(
      io.kubernetes.client.openapi.models.V1DaemonSetConditionFluent<?> fluent,
      io.kubernetes.client.openapi.models.V1DaemonSetCondition instance) {
    this(fluent, instance, false);
  }

  public V1DaemonSetConditionBuilder(
      io.kubernetes.client.openapi.models.V1DaemonSetConditionFluent<?> fluent,
      io.kubernetes.client.openapi.models.V1DaemonSetCondition instance,
      java.lang.Boolean validationEnabled) {
    this.fluent = fluent;
    fluent.withLastTransitionTime(instance.getLastTransitionTime());

    fluent.withMessage(instance.getMessage());

    fluent.withReason(instance.getReason());

    fluent.withStatus(instance.getStatus());

    fluent.withType(instance.getType());

    this.validationEnabled = validationEnabled;
  }

  public V1DaemonSetConditionBuilder(
      io.kubernetes.client.openapi.models.V1DaemonSetCondition instance) {
    this(instance, false);
  }

  public V1DaemonSetConditionBuilder(
      io.kubernetes.client.openapi.models.V1DaemonSetCondition instance,
      java.lang.Boolean validationEnabled) {
    this.fluent = this;
    this.withLastTransitionTime(instance.getLastTransitionTime());

    this.withMessage(instance.getMessage());

    this.withReason(instance.getReason());

    this.withStatus(instance.getStatus());

    this.withType(instance.getType());

    this.validationEnabled = validationEnabled;
  }

  io.kubernetes.client.openapi.models.V1DaemonSetConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;

  public io.kubernetes.client.openapi.models.V1DaemonSetCondition build() {
    V1DaemonSetCondition buildable = new V1DaemonSetCondition();
    buildable.setLastTransitionTime(fluent.getLastTransitionTime());
    buildable.setMessage(fluent.getMessage());
    buildable.setReason(fluent.getReason());
    buildable.setStatus(fluent.getStatus());
    buildable.setType(fluent.getType());
    return buildable;
  }
}

==> client-java-api-fluent-17.0.2-sources.jar: io/kubernetes/client/openapi/models/V1DaemonSetConditionBuilder.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Boolean;
public class V1DaemonSetConditionBuilder extends V1DaemonSetConditionFluentImpl<V1DaemonSetConditionBuilder> implements VisitableBuilder<V1DaemonSetCondition,V1DaemonSetConditionBuilder>{
  public V1DaemonSetConditionBuilder() {
    this(false);
  }
  public V1DaemonSetConditionBuilder(Boolean validationEnabled) {
    this(new V1DaemonSetCondition(), validationEnabled);
  }
  public V1DaemonSetConditionBuilder(V1DaemonSetConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public V1DaemonSetConditionBuilder(V1DaemonSetConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new V1DaemonSetCondition(), validationEnabled);
  }
  public V1DaemonSetConditionBuilder(V1DaemonSetConditionFluent<?> fluent,V1DaemonSetCondition instance) {
    this(fluent, instance, false);
  }
  public V1DaemonSetConditionBuilder(V1DaemonSetConditionFluent<?> fluent,V1DaemonSetCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime());

    fluent.withMessage(instance.getMessage());

    fluent.withReason(instance.getReason());

    fluent.withStatus(instance.getStatus());

    fluent.withType(instance.getType());

    this.validationEnabled = validationEnabled; 
  }
  public V1DaemonSetConditionBuilder(V1DaemonSetCondition instance) {
    this(instance,false);
  }
  public V1DaemonSetConditionBuilder(V1DaemonSetCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime());

    this.withMessage(instance.getMessage());

    this.withReason(instance.getReason());

    this.withStatus(instance.getStatus());

    this.withType(instance.getType());

    this.validationEnabled = validationEnabled; 
  }
  V1DaemonSetConditionFluent<?> fluent;
  Boolean validationEnabled;
  public V1DaemonSetCondition build() {
    V1DaemonSetCondition buildable = new V1DaemonSetCondition();
    buildable.setLastTransitionTime(fluent.getLastTransitionTime());
    buildable.setMessage(fluent.getMessage());
    buildable.setReason(fluent.getReason());
    buildable.setStatus(fluent.getStatus());
    buildable.setType(fluent.getType());
    return buildable;
  }
  
}
